==> blue2-click-collect-plugin-1.7.1-752768.tar: src/Order/OrderItem.php <==
<?php

namespace B2\Order;

class OrderItem
{
    private $orderItemData;
    private $itemKey;
    private $orderId;

    public function __construct($orderItemData, $itemKey, $orderId)
    {
        $this->orderItemData = $orderItemData;
        $this->itemKey = $itemKey;
        $this->orderId = $orderId;
    }

    public function getTotal()
    {
        return $this->orderItemData->get_total();
    }

    public function newOrderItemData()
    {
        $newItemArray = [
            'product_thumbnail' => $this->getThumbnail(),
            'product_title' => $this->getOrderName(),
            'weight' => $this->getOrderItemWeight(),
            'weight_for_one' => $this->getWeightForOne(),
            'unit_label' => $this->getUnitLabel(),
            'unit' => floor($this->getNoOfPeople()),
            'size' => $this->getPackSize(),
            'qty' => $this->getQuantity(),
            'sku' => $this->getSKU(),
        ];

        return $newItemArray;
    }

    public function getThumbnail()
    {
        if (get_the_post_thumbnail_url($this->getProductId(), 'thumbnail')) {
            return get_the_post_thumbnail_url($this->getProductId(), 'thumbnail');
        } else {
            return 'https://d1ssu070pg2v9i.cloudfront.net/pex/simonhowie/2019/02/04095001/default-image-950x950-150x150.jpg';
        }
    }

    public function getProductId()
    {
        return $this->orderItemData->get_product_id();
    }

    public function getOrderName()
    {
        return $this->orderItemData->get_name();
    }

    public function getOrderItemWeight()
    {
        if (wc_get_order_item_meta($this->itemKey, 'Required Weight (g)')) {
            return wc_get_order_item_meta($this->itemKey, 'Required Weight (g)');
        } elseif (wc_get_order_item_meta($this->itemKey, 'Weight (g)')) {
            return wc_get_order_item_meta($this->itemKey, 'Weight (g)');
        } else {
            return '';
        }
    }

    public function getWeightForOne()
    {
        if (array_key_exists('weight_of_one_unit', $this->getProductMeta())) {
            return $this->getProductMeta()['weight_of_one_unit'][0];
        } else {
            return @$this->getProductMeta()['weight_to_feed_one_person'][0];
        }
    }

    public function getProductMeta()
    {
        return get_post_meta($this->getProductId());
    }

    public function getUnitLabel()
    {
        if (array_key_exists('unit_label', $this->getProductMeta())) {
            return $this->getProductMeta()['unit_label'][0];
        } elseif ($this->getWeightForOne() > 0) {
            return 'People';
        } else {
            return '';
        }
    }

    public function getNoOfPeople()
    {
        if ($this->getWeightForOne() > 0) {
            return ($this->getOrderItemWeight() && $this->getWeightForOne() > 0 ? ($this->getOrderItemWeight() / $this->getWeightForOne()) : '');
        } elseif (array_key_exists('unit_label', $this->getProductMeta())) {
            return $this->getProductMeta()['unit_label'][0];
        }
    }

    public function getPackSize()
    {
        $packSize = new OrderPackSize($this->getProduct());
        return ($packSize->getPackSize() ? $packSize->getPackSize() : '');
    }

    public function getProduct()
    {
        return $this->orderItemData->get_product();
    }

    public function getQuantity()
    {
        return $this->orderItemData->get_quantity();
    }

    public function getSKU()
    {
        $product = wc_get_product($this->getProductId());
        return $product->get_sku();
    }
}

==> blue2-click-collect-plugin-1.7.5-5b490b.tar: src/Order/OrderItem.php <==
<?php

namespace B2\Order;

class OrderItem
{
    private $orderItemData;
    private $itemKey;
    private $orderId;

    public function __construct($orderItemData, $itemKey, $orderId)
    {
        $this->orderItemData = $orderItemData;
        $this->itemKey = $itemKey;
        $this->orderId = $orderId;
    }

    public function getTotal()
    {
        return $this->orderItemData->get_total();
    }

    public function newOrderItemData()
    {
        $newItemArray = [
            'product_thumbnail' => $this->getThumbnail(),
            'product_title' => $this->getOrderName(),
            'weight' => $this->getOrderItemWeight(),
            'weight_for_one' => $this->getWeightForOne(),
            'unit_label' => $this->getUnitLabel(),
            'unit' => floor($this->getNoOfPeople()),
            'size' => $this->getPackSize(),
            'qty' => $this->getQuantity(),
            'sku' => $this->getSKU(),
            'custom-options' => $this->getCustomOptions(),
        ];

        return $newItemArray;
    }

    public function getThumbnail()
    {
        if (get_the_post_thumbnail_url($this->getProductId(), 'thumbnail')) {
            return get_the_post_thumbnail_url($this->getProductId(), 'thumbnail');
        } else {
            return 'https://d1ssu070pg2v9i.cloudfront.net/pex/simonhowie/2019/02/04095001/default-image-950x950-150x150.jpg';
        }
    }

    public function getProductId()
    {
        return $this->orderItemData->get_product_id();
    }

    public function getOrderName()
    {
        return $this->orderItemData->get_name();
    }

    public function getOrderItemWeight()
    {
        if (wc_get_order_item_meta($this->itemKey, 'Required Weight (g)')) {
            return wc_get_order_item_meta($this->itemKey, 'Required Weight (g)');
        } elseif (wc_get_order_item_meta($this->itemKey, 'Weight (g)')) {
            return wc_get_order_item_meta($this->itemKey, 'Weight (g)');
        } else {
            return '';
        }
    }

    public function getWeightForOne()
    {
        if (array_key_exists('weight_of_one_unit', $this->getProductMeta())) {
            return $this->getProductMeta()['weight_of_one_unit'][0];
        } else {
            return @$this->getProductMeta()['weight_to_feed_one_person'][0];
        }
    }

    public function getProductMeta()
    {
        return get_post_meta($this->getProductId());
    }

    public function getUnitLabel()
    {
        if (array_key_exists('unit_label', $this->getProductMeta())) {
            return $this->getProductMeta()['unit_label'][0];
        } elseif ($this->getWeightForOne() > 0) {
            return 'People';
        } else {
            return '';
        }
    }

    public function getNoOfPeople()
    {
        if ($this->getWeightForOne() > 0) {
            return ($this->getOrderItemWeight() && $this->getWeightForOne() > 0 ? ($this->getOrderItemWeight() / $this->getWeightForOne()) : '');
        } elseif (array_key_exists('unit_label', $this->getProductMeta())) {
            return $this->getProductMeta()['unit_label'][0];
        }
    }

    public function getPackSize()
    {
        $packSize = new OrderPackSize($this->getProduct());
        return ($packSize->getPackSize() ? $packSize->getPackSize() : '');
    }

    public function getProduct()
    {
        return $this->orderItemData->get_product();
    }

    public function getQuantity()
    {
        return $this->orderItemData->get_quantity();
    }

    public function getSKU()
    {
        $product = wc_get_product($this->getProductId());
        return $product->get_sku();
    }
    
    public function getCustomOptions()()
    {        
        return get_post_meta( $this->getProductId(), '_custom_options' );;
    }
}
